summaryrefslogtreecommitdiff
path: root/test/test_testing.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/test_testing.py')
-rw-r--r--test/test_testing.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/test/test_testing.py b/test/test_testing.py
index 5d1ac0bc..4208c1d1 100644
--- a/test/test_testing.py
+++ b/test/test_testing.py
@@ -2,12 +2,12 @@
import os, sys
sys.path.insert(0, os.path.split(__file__)[0]) # Force relative import for Py3k
-from coveragetest import CoverageTest
+from backunittest import TestCase
from coverage.backward import set # pylint: disable-msg=W0622
-class TestingTest(CoverageTest):
- """Tests of helper methods on CoverageTest."""
+class TestingTest(TestCase):
+ """Tests of helper methods on `backunittest.TestCase`."""
run_in_temp_dir = False